# RPM spec file for OpenStack on RHEL 6
# Some bits borrowed from the katello-selinux package

%global selinuxtype	targeted
%global moduletype	services
%global modulenames	openstack-selinux-nova openstack-selinux-neutron swift openstack-rsync

# Usage: _format var format
#   Expand 'modulenames' into various formats as needed
#   Format must contain '$x' somewhere to do anything useful
%global _format() export %1=""; for x in %{modulenames}; do %1+=%2; %1+=" "; done;

# We do this in post install and post uninstall phases
%global relabel_files() \
	/sbin/restorecon -Rv %{_bindir}/swift* %{_localstatedir}/run/swift /srv %{_bindir}/neutron* &> /dev/null || :\

# Version of SELinux we were using
%global selinux_policyver 3.7.19-231.el6

# Package information
Name:			openstack-selinux
Version:		0.1.3
Release:		2%{?dist}
License:		GPLv2
Group:			System Environment/Base
Summary:		SELinux Policies for OpenStack
BuildArch:		noarch
URL:			https://github.com/lhh/%{name}
Requires:		policycoreutils, libselinux-utils
Requires(post):		selinux-policy-base >= %{selinux_policyver}, selinux-policy-targeted >= %{selinux_policyver}, policycoreutils, policycoreutils-python
Requires(postun):	policycoreutils
BuildRequires:		selinux-policy selinux-policy-devel

#
# wget -c https://github.com/lhh/%{name}/archive/%{version}.tar.gz \
#    -O %{name}-%{version}.tar.gz
#
Source:			%{name}-%{version}.tar.gz

%description
SELinux policy modules for use with OpenStack

%prep
%setup -q

%build
make SHARE="%{_datadir}" TARGETS="%{modulenames}"

%install

# Install SELinux interfaces
%_format INTERFACES $x.if
install -d %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -p -m 644 $INTERFACES \
	%{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}

# Install policy modules
%_format MODULES $x.pp.bz2
install -d %{buildroot}%{_datadir}/selinux/packages
install -m 0644 $MODULES \
	%{buildroot}%{_datadir}/selinux/packages

%post
# If upgrading, stop using old module
if [ $1 -eq 2 ]; then
	%{_sbindir}/semodule -n -r %{modulenames} || :
fi

#
# Install all modules in a single transaction
#
%_format MODULES %{_datadir}/selinux/packages/$x.pp.bz2
%{_sbindir}/semodule -n -s %{selinuxtype} -i $MODULES

if %{_sbindir}/selinuxenabled ; then
	%{_sbindir}/load_policy

	# bz#1020052: set correct contexts for neutron
	%{_sbindir}/semanage fcontext -a -t neutron_exec_t %{_bindir}/neutron-lbaas-agent
	%{_sbindir}/semanage fcontext -a -t neutron_exec_t %{_bindir}/neutron-rootwrap
	# bz#1039204
	%{_sbindir}/semanage fcontext -a -t neutron_exec_t %{_bindir}/neutron-vpn-agent

	%relabel_files
fi


%postun
if [ $1 -eq 0 ]; then
	%{_sbindir}/semodule -n -r %{modulenames} || :
	if %{_sbindir}/selinuxenabled ; then
		%{_sbindir}/load_policy
		%relabel_files
	fi
fi


%files
%defattr(-,root,root,0755)
%doc COPYING
%attr(0644,root,root) %{_datadir}/selinux/packages/*.pp.bz2
%attr(0644,root,root) %{_datadir}/selinux/devel/include/%{moduletype}/*.if

%changelog
* Mon Dec 09 2013 Lon Hohberger <lhh@redhat.com> - 0.1.3-2
- Set neutron-vpn-agent to neutron_exec_t
- Require RHEL 6.5 selinux-policy
  Resolves: rhbz#1039204

* Thu Nov 14 2013 Lon Hohberger <lhh@redhat.com> - 0.1.3-1
- Remove unnecessary policy for LBaaS
- Rebase to 0.1.3
- Correct file contexts in %post for now
  Resolves: rhbz#1020052

* Tue Nov 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-13
- Additional policy additions for LBaaS
  Resolves: rhbz#1020052

* Fri Nov 08 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-12
- Add Neutron LBaaS tunable
  Resolves: rhbz#1020052

* Wed Mar 20 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-11
- Add BuildRequires for selinux-policy-devel
- Fix directory permissions

* Wed Mar 20 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-10
- Depend on later release of selinux-policy since it contains
  fixes for OpenStack Swift's use of GlusterFS 
  Resolves: rhbz#923426

* Tue Mar 19 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-9
- Depend on later release of selinux-policy since it contains
  fixes for OpenStack Quantum
  Resolves: rhbz#923426

* Mon Mar 18 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-8
- Call restorecon on /srv to ensure that previously-created
  Swift objects have the correct SELinux context
  Resolves: rhbz#918721

* Wed Mar 06 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-7
- Add a type and path for swift when using rsync
  Resolves: rhbz#918721

* Tue Mar 05 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-6
- Allow dnsmasq_t to write to quantum's DHCP directory
  Resolves: rhbz#915906

* Fri Feb 22 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-5
- Allow rsync to deal with lock files
  Resolves: rhbz#885529

* Thu Feb 20 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-4
- Fix up changelog for wrong bug
- Ancillary patch for dnsmasq AVC denial
- Resolves: rhbz#889782

* Tue Feb 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-3
- Spec file cleanups

* Tue Feb 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-2
- Spec file cleanups 

* Tue Feb 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.2-1
- Add policy for swift to resolve rsync issues
- Resolves: rhbz#885529

* Tue Feb 12 2013 Lon Hohberger <lhh@redhat.com> - 0.1.1-1
- Add policy for quantum to resolve DHCP lease issues
- Resolves: rhbz#889782

* Mon Feb 11 2013 Lon Hohberger <lhh@redhat.com> - 0.1.0-2
- Fix URL and Source identifiers

* Mon Feb 11 2013 Lon Hohberger <lhh@redhat.com> - 0.1.0-1
- First Build, addreses openstack nova issues
- Resolves: rhbz#913197
